@@ -6,7 +6,9 @@ from .stylespec import validate_stylespec
 
 def validate_labeledcell(field_data):
     def validate_cell(cell):
-        if cell is not None and type(cell) not in [int, dict] and not isinstance(cell, six.string_types):
+        if (cell is not None and
+                type(cell) not in [int, dict] and
+                not isinstance(cell, six.string_types)):
             return False
         if isinstance(cell, dict) and not cell:
             return False
@@ -16,9 +18,12 @@ def validate_labeledcell(field_data):
     if isinstance(field_data, dict):
         if not all(key in ("cell", "style", "value") for key in field_data):
             return False
-        if "cell" in field_data and (isinstance(field_data["cell"], dict) or not validate_cell(field_data["cell"])):
+        if ("cell" in field_data and
+                (isinstance(field_data["cell"], dict) or
+                 not validate_cell(field_data["cell"]))):
             return False
-        if "value" in field_data and not isinstance(field_data["value"], six.string_types):
+        if ("value" in field_data and
+                not isinstance(field_data["value"], six.string_types)):
             return False
         if "style" in field_data:
             try:
